translate.search.match

Package translate :: Package search :: Module match |
[hide private]
[frames] | no frames]

# Module match

source code

Class to perform translation memory matching from a store of translation units

Classes | [hide private]
| matcher A class that will do matching and store configuration for the matching process
| terminologymatcher A matcher with settings specifically for terminology matching

Functions | [hide private]
sourcelen(unit) Returns the length of the source string | source code
_sort_matches(matches, match_info) | source code
unit2dict(unit) converts a pounit to a simple dict structure for use over the web | source code
_parse_quality(comment) extracts match quality from po comments | source code

Variables | [hide private]
| ignorepatterns = `[("y\s*$", "ie"), ("[\s-]+", ""), ("-", " "),`...``
| ignorepatterns_re = `[(re.compile(a), b) for(a, b) in ignorepat`...``
| context_re = `re.compile("\s+\(.*\)\s*$")`

Imports: heapq, re, lshtein, terminology, base, po, multistring

Variables Details | [hide private]

  ### ignorepatterns Value:
      [("y\s*$", "ie"), ("[\s-]+", ""), ("-", " "), (" ", "-"),]

  ### ignorepatterns_re Value:
      [(re.compile(a), b) for(a, b) in ignorepatterns]